package jp.co.hkinet.hkibarcodetest;

import java.text.SimpleDateFormat;
import java.util.Date;

import android.app.AlertDialog;
import android.app.ListActivity;
import android.content.DialogInterface;
import android.content.Intent;
import android.database.Cursor;
import android.net.Uri;
import android.os.Bundle;
import android.text.ClipboardManager;
import android.view.ContextMenu;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.ListView;
import android.widget.SimpleCursorAdapter;
import android.widget.AdapterView;
import android.widget.Toast;
import android.widget.AdapterView.AdapterContextMenuInfo;

public class HistoryListActivity extends ListActivity implements AdapterView.OnItemClickListener
{
    
    Cursor mCursor;
    
	private static final int CLEAR_ID = Menu.FIRST + 1;
	
    private static final int MENU_ID_COPY_TO_CLIPBORAD = 1;
    private static final int MENU_ID_DELETE = 2;

	private static final SimpleDateFormat SDF = new SimpleDateFormat("yyyy/MM/dd HH:mm:ss");

	@Override
    public void onCreate(Bundle savedInstanceState)
    {
        super.onCreate(savedInstanceState);
        
        String[] projection = new String[] { HkiBarcodeTestActivity.ColumnsHistory._ID,
        									 HkiBarcodeTestActivity.ColumnsHistory.TEXT,
        								   };
        
        mCursor = managedQuery(HkiBarcodeTestActivity.CONTENT_URI, projection, null, null, null);

        SimpleCursorAdapter adapter = new SimpleCursorAdapter(this, android.R.layout.simple_list_item_1, mCursor,
                new String[] { HkiBarcodeTestActivity.ColumnsHistory.TEXT },
                new int[] {android.R.id.text1});
        
        ListView listView = getListView();
        listView.setOnItemClickListener(this);
        listView.setAdapter(adapter);

		registerForContextMenu(listView);
    }

    @Override
    public void onItemClick(AdapterView<?> parent, View v, int position, long id)
    {
        mCursor.moveToPosition(position);
        
        Uri uri = Uri.withAppendedPath(HkiBarcodeTestActivity.CONTENT_URI, mCursor.getString(0));
        
        String[] projection = new String[] { HkiBarcodeTestActivity.ColumnsHistory._ID,
        									 HkiBarcodeTestActivity.ColumnsHistory.TEXT,
        									 HkiBarcodeTestActivity.ColumnsHistory.FORMAT,
        									 HkiBarcodeTestActivity.ColumnsHistory.TYPE,
        									 HkiBarcodeTestActivity.ColumnsHistory.TIMESTAMP,
        								   };

        // Get the full record
        Cursor cursor = getContentResolver().query(uri, projection, null, null, HkiBarcodeTestActivity.ColumnsHistory._ID + " ASC");
        cursor.moveToFirst();
/*        
        String message = String.format("ID : %d\nTEXT : %s\nFORMAT : %s\nTYPE : %s\nTIMESTAMP : %s",
        								cursor.getLong(0), 
        								cursor.getString(1),
        								cursor.getString(2),
        								cursor.getString(3),
        								SDF.format(new Date(cursor.getLong(4))));
        Toast.makeText(this, message, Toast.LENGTH_SHORT).show();
*/
		Intent intent = new Intent(getIntent().getAction());
		intent.putExtra(HkiBarcodeTestActivity.ColumnsHistory._ID, cursor.getLong(0));
		intent.putExtra(HkiBarcodeTestActivity.ColumnsHistory.TEXT, cursor.getString(1));
		intent.putExtra(HkiBarcodeTestActivity.ColumnsHistory.FORMAT, cursor.getString(2));
		intent.putExtra(HkiBarcodeTestActivity.ColumnsHistory.TYPE, cursor.getString(3));
		intent.putExtra(HkiBarcodeTestActivity.ColumnsHistory.TIMESTAMP, SDF.format(new Date(cursor.getLong(4))));
		
		setResult(RESULT_OK, intent);
		finish();
    }

	@Override
	public void onCreateContextMenu(ContextMenu menu, View v, ContextMenu.ContextMenuInfo menuInfo)
	{
		super.onCreateContextMenu(menu, v, menuInfo);
		
	    int position = ((AdapterContextMenuInfo)menuInfo).position;

		menu.setHeaderTitle(R.string.history_context_menu_title);

		menu.add(0, MENU_ID_COPY_TO_CLIPBORAD, 0, R.string.menu_copy_to_clipboard);
		menu.add(0, MENU_ID_DELETE, 0, R.string.menu_delete_history);
	}

	@Override
	public boolean onContextItemSelected(MenuItem item)
	{
		AdapterContextMenuInfo info = (AdapterContextMenuInfo)item.getMenuInfo();
		int position = info.position;

        mCursor.moveToPosition(position);
        
        String text = mCursor.getString(1);
        
		if (null == text || text.equals(""))
		{
			return true;
		}

		switch (item.getItemId())
		{
		case MENU_ID_COPY_TO_CLIPBORAD:
			ClipboardManager clipboard = (ClipboardManager) getSystemService(CLIPBOARD_SERVICE);
			clipboard.setText(text);

			Toast.makeText(this ,getString(R.string.msg_copied_to_clipboard) + " \n " + text, Toast.LENGTH_SHORT).show();

			return true;
			
		case MENU_ID_DELETE:
	        Uri uri = Uri.withAppendedPath(HkiBarcodeTestActivity.CONTENT_URI, mCursor.getString(0));
	        
	        int countDeleted = getContentResolver().delete(uri, null, null);

	        if (0 < countDeleted)
	        {
	        	Toast.makeText(this, getString(R.string.msg_deleted) + " \n " + text, Toast.LENGTH_SHORT).show();
	        }
	        else if (0 == countDeleted)
	        {
	        	Toast.makeText(this, getString(R.string.msg_not_exist_history) + " \n " + text, Toast.LENGTH_SHORT).show();
	        }
			return true;
		}

		return super.onContextItemSelected(item);
	}

	@Override
	public boolean onCreateOptionsMenu(Menu menu)
	{
		super.onCreateOptionsMenu(menu);
		
        ListView listView = getListView();
        
        if (0 < listView.getCount())
        {
			menu.add(0, CLEAR_ID, 0, R.string.menu_clear_history).setIcon(android.R.drawable.ic_menu_delete);
			return true;
        }

        return false;
	}

	@Override
	public boolean onOptionsItemSelected(MenuItem item)
	{
		switch (item.getItemId())
		{
		case CLEAR_ID:
			
			AlertDialog.Builder builder = new AlertDialog.Builder(this);
			builder.setMessage(R.string.msg_sure);
			builder.setCancelable(true);
			builder.setPositiveButton(R.string.button_ok, new DialogInterface.OnClickListener()
			{
				@Override
				public void onClick(DialogInterface dialog, int i2)
				{
			        int countDeleted = getContentResolver().delete(HkiBarcodeTestActivity.CONTENT_URI, null, null);

			        if (0 < countDeleted)
			        {
			        	Toast.makeText(HistoryListActivity.this, getString(R.string.msg_deleted), Toast.LENGTH_SHORT).show();
			        }

			        dialog.dismiss();
					finish();
				}
			});
			builder.setNegativeButton(R.string.button_cancel, null);
			builder.show();
			break;
			
		default:
			return super.onOptionsItemSelected(item);
		}
		return true;
	}
}