package jp.co.hkinet.hkibarcodetest;

import android.app.Activity;
import android.content.Intent;
import android.database.Cursor;
import android.net.Uri;
import android.os.Bundle;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.EditText;
import android.widget.TextView;

public class HkiBarcodeTestActivity extends Activity
{
	private static String scanResult;
	private static String scanResultFormat;
	private static String scanResutlType;
	private static long scanResultIdHistory;
	
	private static final int REQUEST_CODE_SCAN = 0;
    private static final int REQUEST_CODE_HISTORY = 1;

    public static final String ACTION_SCAN = "jp.co.hkinet.hkibarcodereader.SCAN";
    public static final Uri CONTENT_URI = Uri.parse("content://jp.co.hkinet.hkibarcodereader.history.historyrovider/historys");

	public static final String RESULT = "SCAN_RESULT";
	public static final String RESULT_FORMAT = "SCAN_RESULT_FORMAT";
	public static final String RESULT_TYPE = "SCAN_RESULT_TYPE";
	public static final String RESULT_ID_HISTORY = "SCAN_RESULT_ID_HISTORY";
	
    static final String TAG_SCAN = "scan";
    static final String TAG_GET_HISTORY = "get_history";
    static final String TAG_HISTORY_LIST = "history_list";

	public static final class ColumnsHistory
    {
        public static final String _ID = "_id";
        public static final String TEXT = "text";
        public static final String FORMAT = "format";
        public static final String TYPE = "type";
        public static final String TIMESTAMP = "timestamp";
    }

	
	/** Called when the activity is first created. */
    @Override
    public void onCreate(Bundle savedInstanceState)
    {
    	super.onCreate(savedInstanceState);
    	setContentView(R.layout.main);

        Button buttonScan = (Button)findViewById(R.id.button_scan);
        buttonScan.setTag(TAG_SCAN);
        buttonScan.setOnClickListener(buttonClickListener); 

        Button buttonHistoryList = (Button)findViewById(R.id.button_history_list);
        buttonHistoryList.setTag(TAG_HISTORY_LIST);
        buttonHistoryList.setOnClickListener(buttonClickListener); 

        Button buttonGetHistory = (Button)findViewById(R.id.button_get_history);
        buttonGetHistory.setTag(TAG_GET_HISTORY);
        buttonGetHistory.setOnClickListener(buttonClickListener); 
    }
    
	@Override
	protected void onResume()
    {
    	updateDisplay();
    	
		super.onResume();
	}

    @Override
    public void onPause()
    {
        super.onPause();
    }
    
    private void updateDisplay()
    {
        TextView scanResultTextView = (TextView)findViewById(R.id.scan_result_textview);
		scanResultTextView.setText(scanResult);

        TextView scanResultFormatTextView = (TextView)findViewById(R.id.scan_result_format_textview);
		scanResultFormatTextView.setText(scanResultFormat);

		TextView scanResultTypeTextView = (TextView)findViewById(R.id.scan_result_type_textview);
		scanResultTypeTextView.setText(scanResutlType);

		TextView scanResultIdHistoryTextView = (TextView)findViewById(R.id.scan_result_id_history_textview);
		scanResultIdHistoryTextView.setText(String.valueOf(scanResultIdHistory));
    }

    // Button click listener
    private OnClickListener buttonClickListener = new OnClickListener()
    {
        @Override
        public void onClick(View v)
        {
            // Get tag of button
            String tag = (String)((Button)v).getTag();

    		if (tag.equals(TAG_SCAN))
    		{
    			Intent intent = new Intent(ACTION_SCAN);
    			//intent.putExtra("SCAN_MODE", "ONE_D_MODE");
    			//intent.putExtra("SCAN_MODE", "PRODUCT_MODE");
    			//intent.putExtra("SCAN_WIDTH", 800);
    			//intent.putExtra("SCAN_HEIGHT", 200);
    			//intent.putExtra("RESULT_DISPLAY_DURATION_MS", 3000L);
    			//intent.putExtra("PROMPT_MESSAGE", "Custom prompt to scan a product");
    			startActivityForResult(intent, REQUEST_CODE_SCAN);
    		}
    		else if (tag.equals(TAG_GET_HISTORY))
    		{
    			EditText scanResultIdHistoryTextView = (EditText)findViewById(R.id.get_id_history_edittext);
    			String idToGetHistory = scanResultIdHistoryTextView.getText().toString();
    			
    			if (null == idToGetHistory || idToGetHistory.equals(""))
    			{
    				return;
    			}
    			
    			// To get one history by history id, append the history id.
    			Uri uri = Uri.withAppendedPath(CONTENT_URI, idToGetHistory);
    			
    			String[] projection = new String[]
    				{
    					ColumnsHistory._ID,
    					ColumnsHistory.TEXT,
    					ColumnsHistory.FORMAT,
    					ColumnsHistory.TYPE,
    	        	};

    	        Cursor cursor = getContentResolver().query(uri, projection, null, null, null);
    			
    			if (null != cursor && 0 < cursor.getCount())
    			{
    				cursor.moveToLast();
    				
    				// 検索結果の取得
    				scanResultIdHistory = cursor.getLong(0);
    				scanResult = cursor.getString(1);
    				scanResultFormat = cursor.getString(2);
    				scanResutlType = cursor.getString(3);
    			}
    			else
    			{
    				scanResultIdHistory = -1;
    				scanResult = "";
    				scanResultFormat = "";
    				scanResutlType = "";
    			}

    			updateDisplay();
    		}
    		else if (tag.equals(TAG_HISTORY_LIST))
    		{
    			Intent intent = new Intent(HkiBarcodeTestActivity.this, HistoryListActivity.class);
    			startActivityForResult(intent, REQUEST_CODE_HISTORY);
    		}
        }
    };

    @Override
	protected void onActivityResult(int requestCode, int resultCode, Intent data)
	{
		super.onActivityResult(requestCode, resultCode, data);
		
		if (requestCode == REQUEST_CODE_SCAN)
		{
			if (resultCode == RESULT_OK)
			{
				// Get scan result
				scanResult = data.getStringExtra(RESULT);
				scanResultFormat = data.getStringExtra(RESULT_FORMAT);
				scanResutlType = data.getStringExtra(RESULT_TYPE);
				scanResultIdHistory = data.getLongExtra(RESULT_ID_HISTORY, -1);
			}
			else
			{
				scanResult = "";
				scanResultFormat = "";
				scanResutlType = "";
				scanResultIdHistory = -1;
			}
		}
		else if (requestCode == REQUEST_CODE_HISTORY)
		{
			if (resultCode == RESULT_OK)
			{
				// Get history result
				scanResult = data.getStringExtra(ColumnsHistory.TEXT);
				scanResultFormat = data.getStringExtra(ColumnsHistory.FORMAT);
				scanResutlType = data.getStringExtra(ColumnsHistory.TYPE);
				scanResultIdHistory = data.getLongExtra(ColumnsHistory._ID, -1);
			}
			else
			{
				scanResult = "";
				scanResultFormat = "";
				scanResutlType = "";
				scanResultIdHistory = -1;
			}
		}
	}

}
